[nautilus-actions/file-manager-actions] NADataBoxed class is renamed to FMADataBoxed



commit 02dece020c5a81bf76eb2c5ac7d2ce1bc2d642cc
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 20:45:43 2015 +0200

    NADataBoxed class is renamed to FMADataBoxed

 src/api/Makefile.am                            |    2 +-
 src/api/fma-data-boxed.h                       |  112 ++++++++++++
 src/api/na-data-boxed.h                        |  112 ------------
 src/api/na-data-def.h                          |    6 +-
 src/api/na-data-types.h                        |    6 +-
 src/api/na-icontext.h                          |    2 +-
 src/api/na-ifactory-object.h                   |    4 +-
 src/api/na-ifactory-provider.h                 |   14 +-
 src/core/Makefile.am                           |    2 +-
 src/core/{na-data-boxed.c => fma-data-boxed.c} |  228 ++++++++++++------------
 src/core/na-factory-object.c                   |   92 +++++-----
 src/core/na-factory-object.h                   |    4 +-
 src/core/na-factory-provider.c                 |   10 +-
 src/core/na-factory-provider.h                 |    6 +-
 src/core/na-ifactory-object.c                  |   10 +-
 src/core/na-ifactory-provider.c                |    2 +-
 src/core/na-object-action.c                    |    4 +-
 src/io-desktop/nadp-reader.c                   |   14 +-
 src/io-desktop/nadp-reader.h                   |    2 +-
 src/io-desktop/nadp-writer.c                   |    6 +-
 src/io-desktop/nadp-writer.h                   |    2 +-
 src/io-gconf/nagp-reader.c                     |   12 +-
 src/io-gconf/nagp-reader.h                     |    2 +-
 src/io-gconf/nagp-writer.c                     |    6 +-
 src/io-gconf/nagp-writer.h                     |    4 +-
 src/io-xml/naxml-reader.c                      |   12 +-
 src/io-xml/naxml-reader.h                      |    4 +-
 src/io-xml/naxml-writer.c                      |   26 ++--
 src/io-xml/naxml-writer.h                      |    4 +-
 29 files changed, 355 insertions(+), 355 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index b0ba8b5..637d4ed 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -39,7 +39,7 @@ api_include_HEADERS = \
        \
        fma-boxed.h                                                                                     \
        fma-core-utils.h                                                                                \
-       na-data-boxed.h                                                                         \
+       fma-data-boxed.h                                                                                \
        na-data-def.h                                                                           \
        na-data-types.h                                                                         \
        na-gconf-monitor.h                                                                      \
diff --git a/src/api/fma-data-boxed.h b/src/api/fma-data-boxed.h
new file mode 100644
index 0000000..5077f8c
--- /dev/null
+++ b/src/api/fma-data-boxed.h
@@ -0,0 +1,112 @@
+/*
+ * FileManager-Actions
+ * A file-manager extension which offers configurable context menu actions.
+ *
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2015 Pierre Wieser and others (see AUTHORS)
+ *
+ * FileManager-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * FileManager-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with FileManager-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz grumz net>
+ *   Rodrigo Moya <rodrigo gnome-db org>
+ *   Pierre Wieser <pwieser trychlos org>
+ *   ... and many others (see AUTHORS)
+ */
+
+#ifndef __FILE_MANAGER_ACTIONS_API_DATA_BOXED_H__
+#define __FILE_MANAGER_ACTIONS_API_DATA_BOXED_H__
+
+/**
+ * SECTION: data-boxed
+ * @title: FMADataBoxed
+ * @short_description: The Data Factory Element Class Definition
+ * @include: file-manager-actions/fma-data-boxed.h
+ *
+ * The object which encapsulates an elementary data of #NAIFactoryObject.
+ * A #FMADataBoxed object has a type and a value.
+ *
+ * #FMADataBoxed class is derived from #FMABoxed one, and implements the same
+ * types that those defined in na-data-types.h.
+ *
+ * Additionally, #FMADataBoxed class holds the #NADataDef data definition
+ * suitable for a NAFactoryObject object. It such provides default value
+ * and validity status.
+ *
+ * Since: 2.30
+ */
+
+#include <glib-object.h>
+
+#include "fma-boxed.h"
+#include "na-data-def.h"
+
+G_BEGIN_DECLS
+
+#define FMA_TYPE_DATA_BOXED                ( fma_data_boxed_get_type())
+#define FMA_DATA_BOXED( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_DATA_BOXED, 
FMADataBoxed ))
+#define FMA_DATA_BOXED_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_DATA_BOXED, 
FMADataBoxedClass ))
+#define FMA_IS_DATA_BOXED( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_DATA_BOXED ))
+#define FMA_IS_DATA_BOXED_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_DATA_BOXED ))
+#define FMA_DATA_BOXED_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_DATA_BOXED, 
FMADataBoxedClass ))
+
+typedef struct _FMADataBoxedPrivate        FMADataBoxedPrivate;
+
+typedef struct {
+       /*< private >*/
+       FMABoxed             parent;
+       FMADataBoxedPrivate *private;
+}
+       FMADataBoxed;
+
+typedef struct _FMADataBoxedClassPrivate   FMADataBoxedClassPrivate;
+
+typedef struct {
+       /*< private >*/
+       FMABoxedClass             parent;
+       FMADataBoxedClassPrivate *private;
+}
+       FMADataBoxedClass;
+
+GType             fma_data_boxed_get_type( void );
+
+FMADataBoxed     *fma_data_boxed_new            ( const NADataDef *def );
+
+const NADataDef *fma_data_boxed_get_data_def   ( const FMADataBoxed *boxed );
+void              fma_data_boxed_set_data_def   ( FMADataBoxed *boxed, const NADataDef *def );
+
+GParamSpec       *fma_data_boxed_get_param_spec ( const NADataDef *def );
+
+gboolean          fma_data_boxed_is_default     ( const FMADataBoxed *boxed );
+gboolean          fma_data_boxed_is_valid       ( const FMADataBoxed *boxed );
+
+/* These functions are deprecated starting with 3.1.0
+ */
+#ifdef NA_ENABLE_DEPRECATED
+gboolean          fma_data_boxed_are_equal      ( const FMADataBoxed *a, const FMADataBoxed *b );
+void              fma_data_boxed_dump           ( const FMADataBoxed *boxed );
+gchar            *fma_data_boxed_get_as_string  ( const FMADataBoxed *boxed );
+void              fma_data_boxed_get_as_value   ( const FMADataBoxed *boxed, GValue *value );
+void             *fma_data_boxed_get_as_void    ( const FMADataBoxed *boxed );
+void              fma_data_boxed_set_from_boxed ( FMADataBoxed *boxed, const FMADataBoxed *value );
+void              fma_data_boxed_set_from_string( FMADataBoxed *boxed, const gchar *value );
+void              fma_data_boxed_set_from_value ( FMADataBoxed *boxed, const GValue *value );
+void              fma_data_boxed_set_from_void  ( FMADataBoxed *boxed, const void *value );
+#endif /* NA_ENABLE_DEPRECATED */
+
+G_END_DECLS
+
+#endif /* __FILE_MANAGER_ACTIONS_API_DATA_BOXED_H__ */
diff --git a/src/api/na-data-def.h b/src/api/na-data-def.h
index be98840..0fd28f8 100644
--- a/src/api/na-data-def.h
+++ b/src/api/na-data-def.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_FACTORY_DATA_DEF_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_FACTORY_DATA_DEF_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_DATA_DEF_H__
+#define __FILE_MANAGER_ACTIONS_API_DATA_DEF_H__
 
 /**
  * SECTION: data-def
@@ -142,4 +142,4 @@ const NADataDef *na_data_def_get_data_def( const NADataGroup *group, const gchar
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_FACTORY_DATA_DEF_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_DATA_DEF_H__ */
diff --git a/src/api/na-data-types.h b/src/api/na-data-types.h
index 563803a..d5fb51b 100644
--- a/src/api/na-data-types.h
+++ b/src/api/na-data-types.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_DATA_TYPES_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_DATA_TYPES_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_DATA_TYPES_H__
+#define __FILE_MANAGER_ACTIONS_API_DATA_TYPES_H__
 
 /**
  * SECTION: data-type
@@ -91,4 +91,4 @@ const gchar *na_data_types_get_gconf_dump_key( guint type );
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_DATA_TYPES_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_DATA_TYPES_H__ */
diff --git a/src/api/na-icontext.h b/src/api/na-icontext.h
index c28dd72..8a2ab26 100644
--- a/src/api/na-icontext.h
+++ b/src/api/na-icontext.h
@@ -41,7 +41,7 @@
  * conditions.
  *
  * Implementors, typically #NAObjectAction, #NAObjectProfile and
- * #NAObjectMenu, host the required data as #NADataBoxed in a dedicated
+ * #NAObjectMenu, host the required data as #FMADataBoxed in a dedicated
  * NA_FACTORY_CONDITIONS_GROUP data group.
  */
 
diff --git a/src/api/na-ifactory-object.h b/src/api/na-ifactory-object.h
index 6e6f3ca..85b150f 100644
--- a/src/api/na-ifactory-object.h
+++ b/src/api/na-ifactory-object.h
@@ -77,7 +77,7 @@
  */
 
 #include "na-data-def.h"
-#include "na-data-boxed.h"
+#include "fma-data-boxed.h"
 #include "na-ifactory-provider-provider.h"
 
 G_BEGIN_DECLS
@@ -238,7 +238,7 @@ typedef struct {
 
 GType        na_ifactory_object_get_type( void );
 
-NADataBoxed *na_ifactory_object_get_data_boxed ( const NAIFactoryObject *object, const gchar *name );
+FMADataBoxed *na_ifactory_object_get_data_boxed ( const NAIFactoryObject *object, const gchar *name );
 NADataGroup *na_ifactory_object_get_data_groups( const NAIFactoryObject *object );
 void        *na_ifactory_object_get_as_void    ( const NAIFactoryObject *object, const gchar *name );
 void         na_ifactory_object_set_from_void  ( NAIFactoryObject *object, const gchar *name, const void 
*data );
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 5dcf282..314f5c2 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -55,7 +55,7 @@ libna_core_la_SOURCES = \
        na-about.h                                                                                      \
        fma-boxed.c                                                                                     \
        fma-core-utils.c                                                                                \
-       na-data-boxed.c                                                                         \
+       fma-data-boxed.c                                                                                \
        na-data-def.c                                                                           \
        na-data-types.c                                                                         \
        na-desktop-environment.c                                                        \
diff --git a/src/core/na-data-boxed.c b/src/core/fma-data-boxed.c
similarity index 71%
rename from src/core/na-data-boxed.c
rename to src/core/fma-data-boxed.c
index 7d9a19c..e9d6886 100644
--- a/src/core/na-data-boxed.c
+++ b/src/core/fma-data-boxed.c
@@ -39,11 +39,11 @@
 #include <api/na-gconf-utils.h>
 #include <api/na-data-def.h>
 #include <api/na-data-types.h>
-#include <api/na-data-boxed.h>
+#include <api/fma-data-boxed.h>
 
 /* private class data
  */
-struct _NADataBoxedClassPrivate {
+struct _FMADataBoxedClassPrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
@@ -53,14 +53,14 @@ struct _NADataBoxedClassPrivate {
 typedef struct {
        guint           type;
        GParamSpec * ( *spec )      ( const NADataDef * );
-       gboolean     ( *is_default )( const NADataBoxed * );
-       gboolean     ( *is_valid )  ( const NADataBoxed * );
+       gboolean     ( *is_default )( const FMADataBoxed * );
+       gboolean     ( *is_valid )  ( const FMADataBoxed * );
 }
        DataBoxedDef;
 
 /* private instance data
  */
-struct _NADataBoxedPrivate {
+struct _FMADataBoxedPrivate {
        gboolean            dispose_has_run;
        const NADataDef    *data_def ;
        const DataBoxedDef *boxed_def;
@@ -69,7 +69,7 @@ struct _NADataBoxedPrivate {
 static GObjectClass *st_parent_class   = NULL;
 
 static GType               register_type( void );
-static void                class_init( NADataBoxedClass *klass );
+static void                class_init( FMADataBoxedClass *klass );
 static void                instance_init( GTypeInstance *instance, gpointer klass );
 static void                instance_dispose( GObject *object );
 static void                instance_finalize( GObject *object );
@@ -77,31 +77,31 @@ static void                instance_finalize( GObject *object );
 static const DataBoxedDef *get_data_boxed_def( guint type );
 
 static GParamSpec         *bool_spec( const NADataDef *idtype );
-static gboolean            bool_is_default( const NADataBoxed *boxed );
-static gboolean            bool_is_valid( const NADataBoxed *boxed );
+static gboolean            bool_is_default( const FMADataBoxed *boxed );
+static gboolean            bool_is_valid( const FMADataBoxed *boxed );
 
 static GParamSpec         *pointer_spec( const NADataDef *idtype );
-static gboolean            pointer_is_default( const NADataBoxed *boxed );
-static gboolean            pointer_is_valid( const NADataBoxed *boxed );
+static gboolean            pointer_is_default( const FMADataBoxed *boxed );
+static gboolean            pointer_is_valid( const FMADataBoxed *boxed );
 
 static GParamSpec         *string_spec( const NADataDef *idtype );
-static gboolean            string_is_default( const NADataBoxed *boxed );
-static gboolean            string_is_valid( const NADataBoxed *boxed );
+static gboolean            string_is_default( const FMADataBoxed *boxed );
+static gboolean            string_is_valid( const FMADataBoxed *boxed );
 
 static GParamSpec         *string_list_spec( const NADataDef *idtype );
-static gboolean            string_list_is_default( const NADataBoxed *boxed );
-static gboolean            string_list_is_valid( const NADataBoxed *boxed );
+static gboolean            string_list_is_default( const FMADataBoxed *boxed );
+static gboolean            string_list_is_valid( const FMADataBoxed *boxed );
 
-static gboolean            locale_is_default( const NADataBoxed *boxed );
-static gboolean            locale_is_valid( const NADataBoxed *boxed );
+static gboolean            locale_is_default( const FMADataBoxed *boxed );
+static gboolean            locale_is_valid( const FMADataBoxed *boxed );
 
 static GParamSpec         *uint_spec( const NADataDef *idtype );
-static gboolean            uint_is_default( const NADataBoxed *boxed );
-static gboolean            uint_is_valid( const NADataBoxed *boxed );
+static gboolean            uint_is_default( const FMADataBoxed *boxed );
+static gboolean            uint_is_valid( const FMADataBoxed *boxed );
 
 static GParamSpec         *uint_list_spec( const NADataDef *idtype );
-static gboolean            uint_list_is_default( const NADataBoxed *boxed );
-static gboolean            uint_list_is_valid( const NADataBoxed *boxed );
+static gboolean            uint_list_is_default( const FMADataBoxed *boxed );
+static gboolean            uint_list_is_valid( const FMADataBoxed *boxed );
 
 static DataBoxedDef st_data_boxed_def[] = {
                { NA_DATA_TYPE_BOOLEAN,
@@ -143,7 +143,7 @@ static DataBoxedDef st_data_boxed_def[] = {
 };
 
 GType
-na_data_boxed_get_type( void )
+fma_data_boxed_get_type( void )
 {
        static GType item_type = 0;
 
@@ -157,32 +157,32 @@ na_data_boxed_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_data_boxed_register_type";
+       static const gchar *thisfn = "fma_data_boxed_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NADataBoxedClass ),
+               sizeof( FMADataBoxedClass ),
                NULL,
                NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NADataBoxed ),
+               sizeof( FMADataBoxed ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( FMA_TYPE_BOXED, "NADataBoxed", &info, 0 );
+       type = g_type_register_static( FMA_TYPE_BOXED, "FMADataBoxed", &info, 0 );
 
        return( type );
 }
 
 static void
-class_init( NADataBoxedClass *klass )
+class_init( FMADataBoxedClass *klass )
 {
-       static const gchar *thisfn = "na_data_boxed_class_init";
+       static const gchar *thisfn = "fma_data_boxed_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -193,19 +193,19 @@ class_init( NADataBoxedClass *klass )
        object_class->dispose = instance_dispose;
        object_class->finalize = instance_finalize;
 
-       klass->private = g_new0( NADataBoxedClassPrivate, 1 );
+       klass->private = g_new0( FMADataBoxedClassPrivate, 1 );
 }
 
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       NADataBoxed *self;
+       FMADataBoxed *self;
 
-       g_return_if_fail( NA_IS_DATA_BOXED( instance ));
+       g_return_if_fail( FMA_IS_DATA_BOXED( instance ));
 
-       self = NA_DATA_BOXED( instance );
+       self = FMA_DATA_BOXED( instance );
 
-       self->private = g_new0( NADataBoxedPrivate, 1 );
+       self->private = g_new0( FMADataBoxedPrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
        self->private->data_def = NULL;
@@ -215,11 +215,11 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *object )
 {
-       NADataBoxed *self;
+       FMADataBoxed *self;
 
-       g_return_if_fail( NA_IS_DATA_BOXED( object ));
+       g_return_if_fail( FMA_IS_DATA_BOXED( object ));
 
-       self = NA_DATA_BOXED( object );
+       self = FMA_DATA_BOXED( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -235,11 +235,11 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
-       NADataBoxed *self;
+       FMADataBoxed *self;
 
-       g_return_if_fail( NA_IS_DATA_BOXED( object ));
+       g_return_if_fail( FMA_IS_DATA_BOXED( object ));
 
-       self = NA_DATA_BOXED( object );
+       self = FMA_DATA_BOXED( object );
 
        g_free( self->private );
 
@@ -252,7 +252,7 @@ instance_finalize( GObject *object )
 static const DataBoxedDef *
 get_data_boxed_def( guint type )
 {
-       static const gchar *thisfn = "na_data_boxed_get_data_boxed_def";
+       static const gchar *thisfn = "fma_data_boxed_get_data_boxed_def";
        int i;
 
        for( i = 0 ; st_data_boxed_def[i].type ; ++i ){
@@ -266,21 +266,21 @@ get_data_boxed_def( guint type )
 }
 
 /**
- * na_data_boxed_new:
+ * fma_data_boxed_new:
  * @def: the #NADataDef definition structure for this boxed.
  *
- * Returns: a newly allocated #NADataBoxed.
+ * Returns: a newly allocated #FMADataBoxed.
  *
  * Since: 2.30
  */
-NADataBoxed *
-na_data_boxed_new( const NADataDef *def )
+FMADataBoxed *
+fma_data_boxed_new( const NADataDef *def )
 {
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        g_return_val_if_fail( def != NULL, NULL );
 
-       boxed = g_object_new( NA_TYPE_DATA_BOXED, NULL );
+       boxed = g_object_new( FMA_TYPE_DATA_BOXED, NULL );
        fma_boxed_set_type( FMA_BOXED( boxed ), def->type );
        boxed->private->data_def = def;
        boxed->private->boxed_def = get_data_boxed_def( def->type );
@@ -289,8 +289,8 @@ na_data_boxed_new( const NADataDef *def )
 }
 
 /**
- * na_data_boxed_get_data_def:
- * @boxed: this #NADataBoxed object.
+ * fma_data_boxed_get_data_def:
+ * @boxed: this #FMADataBoxed object.
  *
  * Returns: a pointer to the #NADataDef structure attached to the object.
  * Should never be %NULL.
@@ -298,11 +298,11 @@ na_data_boxed_new( const NADataDef *def )
  * Since: 2.30
  */
 const NADataDef *
-na_data_boxed_get_data_def( const NADataBoxed *boxed )
+fma_data_boxed_get_data_def( const FMADataBoxed *boxed )
 {
        const NADataDef *def;
 
-       g_return_val_if_fail( NA_IS_DATA_BOXED( boxed ), NULL );
+       g_return_val_if_fail( FMA_IS_DATA_BOXED( boxed ), NULL );
 
        def = NULL;
 
@@ -315,8 +315,8 @@ na_data_boxed_get_data_def( const NADataBoxed *boxed )
 }
 
 /**
- * na_data_boxed_set_data_def:
- * @boxed: this #NADataBoxed object.
+ * fma_data_boxed_set_data_def:
+ * @boxed: this #FMADataBoxed object.
  * @def: the new #NADataDef to be set.
  *
  * Changes the #NADataDef a @boxed points to:
@@ -326,9 +326,9 @@ na_data_boxed_get_data_def( const NADataBoxed *boxed )
  * Since: 2.30
  */
 void
-na_data_boxed_set_data_def( NADataBoxed *boxed, const NADataDef *new_def )
+fma_data_boxed_set_data_def( FMADataBoxed *boxed, const NADataDef *new_def )
 {
-       g_return_if_fail( NA_IS_DATA_BOXED( boxed ));
+       g_return_if_fail( FMA_IS_DATA_BOXED( boxed ));
        g_return_if_fail( boxed->private->data_def );
        g_return_if_fail( new_def );
        g_return_if_fail( new_def->type == boxed->private->data_def->type );
@@ -340,7 +340,7 @@ na_data_boxed_set_data_def( NADataBoxed *boxed, const NADataDef *new_def )
 }
 
 /**
- * na_data_boxed_get_param_spec:
+ * fma_data_boxed_get_param_spec:
  * @def: a #NADataDef definition structure.
  *
  * Returns: a #GParamSpec structure.
@@ -348,7 +348,7 @@ na_data_boxed_set_data_def( NADataBoxed *boxed, const NADataDef *new_def )
  * Since: 2.30
  */
 GParamSpec *
-na_data_boxed_get_param_spec( const NADataDef *def )
+fma_data_boxed_get_param_spec( const NADataDef *def )
 {
        GParamSpec *spec;
        const DataBoxedDef *fn;
@@ -369,9 +369,9 @@ na_data_boxed_get_param_spec( const NADataDef *def )
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * na_data_boxed_are_equal:
- * @a: the first #NADataBoxed object.
- * @b: the second #NADataBoxed object.
+ * fma_data_boxed_are_equal:
+ * @a: the first #FMADataBoxed object.
+ * @b: the second #FMADataBoxed object.
  *
  * Returns: %TRUE if the two boxeds are equal, %FALSE else.
  *
@@ -379,30 +379,30 @@ na_data_boxed_get_param_spec( const NADataDef *def )
  * Deprecated: 3.1: Use fma_boxed_are_equal() instead.
  */
 gboolean
-na_data_boxed_are_equal( const NADataBoxed *a, const NADataBoxed *b )
+fma_data_boxed_are_equal( const FMADataBoxed *a, const FMADataBoxed *b )
 {
-       g_return_val_if_fail( NA_IS_DATA_BOXED( a ), FALSE );
-       g_return_val_if_fail( NA_IS_DATA_BOXED( b ), FALSE );
+       g_return_val_if_fail( FMA_IS_DATA_BOXED( a ), FALSE );
+       g_return_val_if_fail( FMA_IS_DATA_BOXED( b ), FALSE );
 
        return( fma_boxed_are_equal( FMA_BOXED( a ), FMA_BOXED( b )));
 }
 #endif /* NA_ENABLE_DEPRECATED */
 
 /**
- * na_data_boxed_is_default:
- * @boxed: this #NADataBoxed object.
+ * fma_data_boxed_is_default:
+ * @boxed: this #FMADataBoxed object.
  *
- * Returns: %TRUE if the #NADataBoxed holds its default value,
+ * Returns: %TRUE if the #FMADataBoxed holds its default value,
  * %FALSE else.
  *
  * Since: 2.30
  */
 gboolean
-na_data_boxed_is_default( const NADataBoxed *boxed )
+fma_data_boxed_is_default( const FMADataBoxed *boxed )
 {
        gboolean is_default;
 
-       g_return_val_if_fail( NA_IS_DATA_BOXED( boxed ), FALSE );
+       g_return_val_if_fail( FMA_IS_DATA_BOXED( boxed ), FALSE );
        g_return_val_if_fail( boxed->private->boxed_def, FALSE );
        g_return_val_if_fail( boxed->private->boxed_def->is_default, FALSE );
 
@@ -417,19 +417,19 @@ na_data_boxed_is_default( const NADataBoxed *boxed )
 }
 
 /**
- * na_data_boxed_is_valid:
- * @boxed: the #NADataBoxed object whose validity is to be checked.
+ * fma_data_boxed_is_valid:
+ * @boxed: the #FMADataBoxed object whose validity is to be checked.
  *
  * Returns: %TRUE if the boxed is valid, %FALSE else.
  *
  * Since: 2.30
  */
 gboolean
-na_data_boxed_is_valid( const NADataBoxed *boxed )
+fma_data_boxed_is_valid( const FMADataBoxed *boxed )
 {
        gboolean is_valid;
 
-       g_return_val_if_fail( NA_IS_DATA_BOXED( boxed ), FALSE );
+       g_return_val_if_fail( FMA_IS_DATA_BOXED( boxed ), FALSE );
        g_return_val_if_fail( boxed->private->boxed_def, FALSE );
        g_return_val_if_fail( boxed->private->boxed_def->is_valid, FALSE );
 
@@ -445,8 +445,8 @@ na_data_boxed_is_valid( const NADataBoxed *boxed )
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * na_data_boxed_dump:
- * @boxed: this #NADataBoxed object.
+ * fma_data_boxed_dump:
+ * @boxed: this #FMADataBoxed object.
  *
  * Dump the content of @boxed.
  *
@@ -454,14 +454,14 @@ na_data_boxed_is_valid( const NADataBoxed *boxed )
  * Deprecated: 3.1: Use fma_boxed_dump() instead.
  */
 void
-na_data_boxed_dump( const NADataBoxed *boxed )
+fma_data_boxed_dump( const FMADataBoxed *boxed )
 {
        fma_boxed_dump( FMA_BOXED( boxed ));
 }
 
 /**
- * na_data_boxed_get_as_string:
- * @boxed: the #NADataBoxed whose value is to be set.
+ * fma_data_boxed_get_as_string:
+ * @boxed: the #FMADataBoxed whose value is to be set.
  *
  * Returns: the value of the @boxed, as a newly allocated string which
  * should be g_free() by the caller.
@@ -470,14 +470,14 @@ na_data_boxed_dump( const NADataBoxed *boxed )
  * Deprecated: 3.1: Use fma_boxed_get_string() instead.
  */
 gchar *
-na_data_boxed_get_as_string( const NADataBoxed *boxed )
+fma_data_boxed_get_as_string( const FMADataBoxed *boxed )
 {
        return( fma_boxed_get_string( FMA_BOXED( boxed )));
 }
 
 /**
- * na_data_boxed_get_as_value:
- * @boxed: the #NADataBoxed whose value is to be set.
+ * fma_data_boxed_get_as_value:
+ * @boxed: the #FMADataBoxed whose value is to be set.
  * @value: the string to be set.
  *
  * Setup @value with the content of the @boxed.
@@ -486,14 +486,14 @@ na_data_boxed_get_as_string( const NADataBoxed *boxed )
  * Deprecated: 3.1: Use fma_boxed_get_as_value() instead.
  */
 void
-na_data_boxed_get_as_value( const NADataBoxed *boxed, GValue *value )
+fma_data_boxed_get_as_value( const FMADataBoxed *boxed, GValue *value )
 {
        fma_boxed_get_as_value( FMA_BOXED( boxed ), value );
 }
 
 /**
- * na_data_boxed_get_as_void:
- * @boxed: the #NADataBoxed whose value is to be set.
+ * fma_data_boxed_get_as_void:
+ * @boxed: the #FMADataBoxed whose value is to be set.
  *
  * Returns: the content of the @boxed.
  *
@@ -505,15 +505,15 @@ na_data_boxed_get_as_value( const NADataBoxed *boxed, GValue *value )
  * Deprecated: 3.1: Use fma_boxed_get_as_void() instead.
  */
 void *
-na_data_boxed_get_as_void( const NADataBoxed *boxed )
+fma_data_boxed_get_as_void( const FMADataBoxed *boxed )
 {
        return( fma_boxed_get_as_void( FMA_BOXED( boxed )));
 }
 
 /**
- * na_data_boxed_set_from_boxed:
- * @boxed: the #NADataBoxed whose value is to be set.
- * @value: the source #NADataBoxed.
+ * fma_data_boxed_set_from_boxed:
+ * @boxed: the #FMADataBoxed whose value is to be set.
+ * @value: the source #FMADataBoxed.
  *
  * Copy value from @value to @boxed.
  *
@@ -521,14 +521,14 @@ na_data_boxed_get_as_void( const NADataBoxed *boxed )
  * Deprecated: 3.1: Use fma_boxed_set_from_boxed() instead.
  */
 void
-na_data_boxed_set_from_boxed( NADataBoxed *boxed, const NADataBoxed *value )
+fma_data_boxed_set_from_boxed( FMADataBoxed *boxed, const FMADataBoxed *value )
 {
        fma_boxed_set_from_boxed( FMA_BOXED( boxed ), FMA_BOXED( value ));
 }
 
 /**
- * na_data_boxed_set_from_string:
- * @boxed: the #NADataBoxed whose value is to be set.
+ * fma_data_boxed_set_from_string:
+ * @boxed: the #FMADataBoxed whose value is to be set.
  * @value: the string to be set.
  *
  * Evaluates the @value and set it to the @boxed.
@@ -537,14 +537,14 @@ na_data_boxed_set_from_boxed( NADataBoxed *boxed, const NADataBoxed *value )
  * Deprecated: 3.1: Use fma_boxed_set_from_string() instead.
  */
 void
-na_data_boxed_set_from_string( NADataBoxed *boxed, const gchar *value )
+fma_data_boxed_set_from_string( FMADataBoxed *boxed, const gchar *value )
 {
        fma_boxed_set_from_string( FMA_BOXED( boxed ), value );
 }
 
 /**
- * na_data_boxed_set_from_value:
- * @boxed: the #NADataBoxed whose value is to be set.
+ * fma_data_boxed_set_from_value:
+ * @boxed: the #FMADataBoxed whose value is to be set.
  * @value: the value whose content is to be got.
  *
  * Evaluates the @value and set it to the @boxed.
@@ -553,14 +553,14 @@ na_data_boxed_set_from_string( NADataBoxed *boxed, const gchar *value )
  * Deprecated: 3.1: Use fma_boxed_set_from_value() instead.
  */
 void
-na_data_boxed_set_from_value( NADataBoxed *boxed, const GValue *value )
+fma_data_boxed_set_from_value( FMADataBoxed *boxed, const GValue *value )
 {
        fma_boxed_set_from_value( FMA_BOXED( boxed ), value );
 }
 
 /**
- * na_data_boxed_set_from_void:
- * @boxed: the #NADataBoxed whose value is to be set.
+ * fma_data_boxed_set_from_void:
+ * @boxed: the #FMADataBoxed whose value is to be set.
  * @value: the value whose content is to be got.
  *
  * Evaluates the @value and set it to the @boxed.
@@ -569,7 +569,7 @@ na_data_boxed_set_from_value( NADataBoxed *boxed, const GValue *value )
  * Deprecated: 3.1: Use fma_boxed_set_from_void() instead.
  */
 void
-na_data_boxed_set_from_void( NADataBoxed *boxed, const void *value )
+fma_data_boxed_set_from_void( FMADataBoxed *boxed, const void *value )
 {
        fma_boxed_set_from_void( FMA_BOXED( boxed ), value );
 }
@@ -587,7 +587,7 @@ bool_spec( const NADataDef *def )
 }
 
 static gboolean
-bool_is_default( const NADataBoxed *boxed )
+bool_is_default( const FMADataBoxed *boxed )
 {
        gboolean is_default = FALSE;
        gboolean default_value;
@@ -601,7 +601,7 @@ bool_is_default( const NADataBoxed *boxed )
 }
 
 static gboolean
-bool_is_valid( const NADataBoxed *boxed )
+bool_is_valid( const FMADataBoxed *boxed )
 {
        return( TRUE );
 }
@@ -622,13 +622,13 @@ pointer_spec( const NADataDef *def )
  *  default value for a pointer)
  */
 static gboolean
-pointer_is_default( const NADataBoxed *boxed )
+pointer_is_default( const FMADataBoxed *boxed )
 {
        return( FALSE );
 }
 
 static gboolean
-pointer_is_valid( const NADataBoxed *boxed )
+pointer_is_valid( const FMADataBoxed *boxed )
 {
        gboolean is_valid = TRUE;
        gconstpointer pointer;
@@ -636,7 +636,7 @@ pointer_is_valid( const NADataBoxed *boxed )
        if( boxed->private->data_def->mandatory ){
                pointer = fma_boxed_get_pointer( FMA_BOXED( boxed ));
                if( !pointer ){
-                       g_debug( "na_data_boxed_pointer_is_valid: invalid %s: mandatory but null", 
boxed->private->data_def->name );
+                       g_debug( "fma_data_boxed_pointer_is_valid: invalid %s: mandatory but null", 
boxed->private->data_def->name );
                        is_valid = FALSE;
                }
        }
@@ -656,7 +656,7 @@ string_spec( const NADataDef *def )
 }
 
 static gboolean
-string_is_default( const NADataBoxed *boxed )
+string_is_default( const FMADataBoxed *boxed )
 {
        gboolean is_default = FALSE;
        gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
@@ -685,14 +685,14 @@ string_is_default( const NADataBoxed *boxed )
 }
 
 static gboolean
-string_is_valid( const NADataBoxed *boxed )
+string_is_valid( const FMADataBoxed *boxed )
 {
        gboolean is_valid = TRUE;
 
        if( boxed->private->data_def->mandatory ){
                gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
                if( !value || !strlen( value )){
-                       g_debug( "na_data_boxed_string_is_valid: invalid %s: mandatory but empty or null", 
boxed->private->data_def->name );
+                       g_debug( "fma_data_boxed_string_is_valid: invalid %s: mandatory but empty or null", 
boxed->private->data_def->name );
                        is_valid = FALSE;
                }
                g_free( value );
@@ -712,7 +712,7 @@ string_list_spec( const NADataDef *def )
 }
 
 static gboolean
-string_list_is_default( const NADataBoxed *boxed )
+string_list_is_default( const FMADataBoxed *boxed )
 {
        gboolean is_default = FALSE;
        gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
@@ -734,14 +734,14 @@ string_list_is_default( const NADataBoxed *boxed )
 }
 
 static gboolean
-string_list_is_valid( const NADataBoxed *boxed )
+string_list_is_valid( const FMADataBoxed *boxed )
 {
        gboolean is_valid = TRUE;
 
        if( boxed->private->data_def->mandatory ){
                gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
                if( !value || !strlen( value )){
-                       g_debug( "na_data_boxed_string_list_is_valid: invalid %s: mandatory but empty or 
null", boxed->private->data_def->name );
+                       g_debug( "fma_data_boxed_string_list_is_valid: invalid %s: mandatory but empty or 
null", boxed->private->data_def->name );
                        is_valid = FALSE;
                }
        }
@@ -750,7 +750,7 @@ string_list_is_valid( const NADataBoxed *boxed )
 }
 
 static gboolean
-locale_is_default( const NADataBoxed *boxed )
+locale_is_default( const FMADataBoxed *boxed )
 {
        gboolean is_default = FALSE;
        gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
@@ -778,14 +778,14 @@ locale_is_default( const NADataBoxed *boxed )
 }
 
 static gboolean
-locale_is_valid( const NADataBoxed *boxed )
+locale_is_valid( const FMADataBoxed *boxed )
 {
        gboolean is_valid = TRUE;
 
        if( boxed->private->data_def->mandatory ){
                gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
                if( !value || !g_utf8_strlen( value, -1 )){
-                       g_debug( "na_data_boxed_locale_is_valid: invalid %s: mandatory but empty or null", 
boxed->private->data_def->name );
+                       g_debug( "fma_data_boxed_locale_is_valid: invalid %s: mandatory but empty or null", 
boxed->private->data_def->name );
                        is_valid = FALSE;
                }
                g_free( value );
@@ -808,7 +808,7 @@ uint_spec( const NADataDef *def )
 }
 
 static gboolean
-uint_is_default( const NADataBoxed *boxed )
+uint_is_default( const FMADataBoxed *boxed )
 {
        gboolean is_default = FALSE;
        guint default_value;
@@ -822,7 +822,7 @@ uint_is_default( const NADataBoxed *boxed )
 }
 
 static gboolean
-uint_is_valid( const NADataBoxed *boxed )
+uint_is_valid( const FMADataBoxed *boxed )
 {
        return( TRUE );
 }
@@ -841,20 +841,20 @@ uint_list_spec( const NADataDef *def )
  * we assume no default for uint list
  */
 static gboolean
-uint_list_is_default( const NADataBoxed *boxed )
+uint_list_is_default( const FMADataBoxed *boxed )
 {
        return( FALSE );
 }
 
 static gboolean
-uint_list_is_valid( const NADataBoxed *boxed )
+uint_list_is_valid( const FMADataBoxed *boxed )
 {
        gboolean is_valid = TRUE;
 
        if( boxed->private->data_def->mandatory ){
                gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
                if( !value || !strlen( value )){
-                       g_debug( "na_data_boxed_uint_list_is_valid: invalid %s: mandatory but empty or null", 
boxed->private->data_def->name );
+                       g_debug( "fma_data_boxed_uint_list_is_valid: invalid %s: mandatory but empty or 
null", boxed->private->data_def->name );
                        is_valid = FALSE;
                }
                g_free( value );
diff --git a/src/core/na-factory-object.h b/src/core/na-factory-object.h
index fb9ece9..368a4b3 100644
--- a/src/core/na-factory-object.h
+++ b/src/core/na-factory-object.h
@@ -42,7 +42,7 @@
 
 G_BEGIN_DECLS
 
-typedef gboolean ( *NAFactoryObjectIterBoxedFn )( const NAIFactoryObject *object, NADataBoxed *boxed, void 
*data );
+typedef gboolean ( *NAFactoryObjectIterBoxedFn )( const NAIFactoryObject *object, FMADataBoxed *boxed, void 
*data );
 
 #define NA_IFACTORY_OBJECT_PROP_DATA                   "na-ifactory-object-prop-data"
 
@@ -54,7 +54,7 @@ void         na_factory_object_iter_on_boxed    ( const NAIFactoryObject *object
 gchar       *na_factory_object_get_default      ( NAIFactoryObject *object, const gchar *name );
 void         na_factory_object_set_defaults     ( NAIFactoryObject *object );
 
-void         na_factory_object_move_boxed       ( NAIFactoryObject *target, const NAIFactoryObject *source, 
NADataBoxed *boxed );
+void         na_factory_object_move_boxed       ( NAIFactoryObject *target, const NAIFactoryObject *source, 
FMADataBoxed *boxed );
 
 void         na_factory_object_copy             ( NAIFactoryObject *target, const NAIFactoryObject *source );
 gboolean     na_factory_object_are_equal        ( const NAIFactoryObject *a, const NAIFactoryObject *b );
diff --git a/src/core/na-factory-provider.h b/src/core/na-factory-provider.h
index 47b91d4..edc960b 100644
--- a/src/core/na-factory-provider.h
+++ b/src/core/na-factory-provider.h
@@ -37,17 +37,17 @@
  * Declare the function only accessed from core library (not published as API).
  */
 
-#include <api/na-data-boxed.h>
+#include <api/fma-data-boxed.h>
 #include <api/na-ifactory-provider.h>
 
 G_BEGIN_DECLS
 
-NADataBoxed *na_factory_provider_read_data ( const NAIFactoryProvider *reader, void *reader_data,
+FMADataBoxed *na_factory_provider_read_data ( const NAIFactoryProvider *reader, void *reader_data,
                                                                        const NAIFactoryObject *object, const 
NADataDef *def,
                                                                        GSList **messages );
 
 guint        na_factory_provider_write_data( const NAIFactoryProvider *writer, void *writer_data,
-                                                                       const NAIFactoryObject *object, const 
NADataBoxed *boxed,
+                                                                       const NAIFactoryObject *object, const 
FMADataBoxed *boxed,
                                                                        GSList **messages );
 
 G_END_DECLS
diff --git a/src/core/na-ifactory-provider.c b/src/core/na-ifactory-provider.c
index d08fc86..d7848ce 100644
--- a/src/core/na-ifactory-provider.c
+++ b/src/core/na-ifactory-provider.c
@@ -159,7 +159,7 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
  * its items. The function takes care of collecting and structuring data,
  * while the callback interface methods #NAIFactoryProviderInterface.read_start(),
  * #NAIFactoryProviderInterface.read_data() and #NAIFactoryProviderInterface.read_done()
- * just have to fill a given #NADataBoxed with the ad-hoc data type.
+ * just have to fill a given #FMADataBoxed with the ad-hoc data type.
  *
  * <example>
  *   <programlisting>
diff --git a/src/core/na-object-action.c b/src/core/na-object-action.c
index e42f946..6a90afd 100644
--- a/src/core/na-object-action.c
+++ b/src/core/na-object-action.c
@@ -465,7 +465,7 @@ read_done_convert_v1_to_v2( NAIFactoryObject *instance )
        static const gchar *thisfn = "na_object_action_read_done_read_done_convert_v1_to_last";
        GList *to_move;
        NADataDef *def;
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
        GList *ibox;
        NAObjectProfile *profile;
 
@@ -494,7 +494,7 @@ read_done_convert_v1_to_v2( NAIFactoryObject *instance )
 
        for( ibox = to_move ; ibox ; ibox = ibox->next ){
                na_factory_object_move_boxed(
-                               NA_IFACTORY_OBJECT( profile ), instance, NA_DATA_BOXED( ibox->data ));
+                               NA_IFACTORY_OBJECT( profile ), instance, FMA_DATA_BOXED( ibox->data ));
        }
 
        return( profile );
diff --git a/src/io-desktop/nadp-reader.c b/src/io-desktop/nadp-reader.c
index 0dc0a37..2ae9839 100644
--- a/src/io-desktop/nadp-reader.c
+++ b/src/io-desktop/nadp-reader.c
@@ -482,11 +482,11 @@ read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectP
  * Returns: NULL if the key has not been found
  * letting the caller deal with default values
  */
-NADataBoxed *
+FMADataBoxed *
 nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages )
 {
        static const gchar *thisfn = "nadp_reader_ifactory_provider_read_data";
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
        gboolean found;
        NadpReaderData *nrd;
        gchar *group, *id;
@@ -524,7 +524,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
                                case NA_DATA_TYPE_LOCALE_STRING:
                                        str_value = nadp_desktop_file_get_locale_string( nrd->ndf, group, 
def->desktop_entry, &found, def->default_value );
                                        if( found ){
-                                               boxed = na_data_boxed_new( def );
+                                               boxed = fma_data_boxed_new( def );
                                                fma_boxed_set_from_void( FMA_BOXED( boxed ), str_value );
                                        }
                                        g_free( str_value );
@@ -533,7 +533,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
                                case NA_DATA_TYPE_STRING:
                                        str_value = nadp_desktop_file_get_string( nrd->ndf, group, 
def->desktop_entry, &found, def->default_value );
                                        if( found ){
-                                               boxed = na_data_boxed_new( def );
+                                               boxed = fma_data_boxed_new( def );
                                                fma_boxed_set_from_void( FMA_BOXED( boxed ), str_value );
                                        }
                                        g_free( str_value );
@@ -542,7 +542,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
                                case NA_DATA_TYPE_BOOLEAN:
                                        bool_value = nadp_desktop_file_get_boolean( nrd->ndf, group, 
def->desktop_entry, &found, fma_core_utils_boolean_from_string( def->default_value ));
                                        if( found ){
-                                               boxed = na_data_boxed_new( def );
+                                               boxed = fma_data_boxed_new( def );
                                                fma_boxed_set_from_void( FMA_BOXED( boxed ), 
GUINT_TO_POINTER( bool_value ));
                                        }
                                        break;
@@ -550,7 +550,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
                                case NA_DATA_TYPE_STRING_LIST:
                                        slist_value = nadp_desktop_file_get_string_list( nrd->ndf, group, 
def->desktop_entry, &found, def->default_value );
                                        if( found ){
-                                               boxed = na_data_boxed_new( def );
+                                               boxed = fma_data_boxed_new( def );
                                                fma_boxed_set_from_void( FMA_BOXED( boxed ), slist_value );
                                        }
                                        fma_core_utils_slist_free( slist_value );
@@ -559,7 +559,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
                                case NA_DATA_TYPE_UINT:
                                        uint_value = nadp_desktop_file_get_uint( nrd->ndf, group, 
def->desktop_entry, &found, atoi( def->default_value ));
                                        if( found ){
-                                               boxed = na_data_boxed_new( def );
+                                               boxed = fma_data_boxed_new( def );
                                                fma_boxed_set_from_void( FMA_BOXED( boxed ), 
GUINT_TO_POINTER( uint_value ));
                                        }
                                        break;
diff --git a/src/io-desktop/nadp-reader.h b/src/io-desktop/nadp-reader.h
index 2c02223..131b20a 100644
--- a/src/io-desktop/nadp-reader.h
+++ b/src/io-desktop/nadp-reader.h
@@ -41,7 +41,7 @@ GList       *nadp_iio_provider_read_items            ( const NAIIOProvider *prov
 guint        nadp_reader_iimporter_import_from_uri   ( const NAIImporter *instance, void *parms_ptr );
 
 void         nadp_reader_ifactory_provider_read_start( const NAIFactoryProvider *reader, void *reader_data, 
const NAIFactoryObject *serializable, GSList **messages );
-NADataBoxed *nadp_reader_ifactory_provider_read_data ( const NAIFactoryProvider *reader, void *reader_data, 
const NAIFactoryObject *serializable, const NADataDef *iddef, GSList **messages );
+FMADataBoxed *nadp_reader_ifactory_provider_read_data ( const NAIFactoryProvider *reader, void *reader_data, 
const NAIFactoryObject *serializable, const NADataDef *iddef, GSList **messages );
 void         nadp_reader_ifactory_provider_read_done ( const NAIFactoryProvider *reader, void *reader_data, 
const NAIFactoryObject *serializable, GSList **messages );
 
 G_END_DECLS
diff --git a/src/io-desktop/nadp-writer.c b/src/io-desktop/nadp-writer.c
index cf68fdd..f127588 100644
--- a/src/io-desktop/nadp-writer.c
+++ b/src/io-desktop/nadp-writer.c
@@ -500,7 +500,7 @@ write_start_write_type( NadpDesktopFile *ndp, NAObjectItem *item )
 guint
 nadp_writer_ifactory_provider_write_data(
                                const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject 
*object,
-                               const NADataBoxed *boxed, GSList **messages )
+                               const FMADataBoxed *boxed, GSList **messages )
 {
        static const gchar *thisfn = "nadp_writer_ifactory_provider_write_data";
        NadpDesktopFile *ndf;
@@ -519,7 +519,7 @@ nadp_writer_ifactory_provider_write_data(
 
        code = NA_IIO_PROVIDER_CODE_OK;
        ndf = NADP_DESKTOP_FILE( writer_data );
-       def = na_data_boxed_get_data_def( boxed );
+       def = fma_data_boxed_get_data_def( boxed );
 
        if( def->desktop_entry && strlen( def->desktop_entry )){
 
@@ -532,7 +532,7 @@ nadp_writer_ifactory_provider_write_data(
                        group_name = g_strdup( NADP_GROUP_DESKTOP );
                }
 
-               if( !na_data_boxed_is_default( boxed ) || def->write_if_default ){
+               if( !fma_data_boxed_is_default( boxed ) || def->write_if_default ){
 
                        switch( def->type ){
 
diff --git a/src/io-desktop/nadp-writer.h b/src/io-desktop/nadp-writer.h
index c562c7e..25de910 100644
--- a/src/io-desktop/nadp-writer.h
+++ b/src/io-desktop/nadp-writer.h
@@ -52,7 +52,7 @@ guint    nadp_writer_ifactory_provider_write_start(
 
 guint    nadp_writer_ifactory_provider_write_data(
                                const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject 
*object,
-                               const NADataBoxed *boxed, GSList **messages );
+                               const FMADataBoxed *boxed, GSList **messages );
 
 guint    nadp_writer_ifactory_provider_write_done(
                                const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject 
*object,
diff --git a/src/io-gconf/nagp-reader.c b/src/io-gconf/nagp-reader.c
index cc37d71..49ed101 100644
--- a/src/io-gconf/nagp-reader.c
+++ b/src/io-gconf/nagp-reader.c
@@ -60,7 +60,7 @@ static gboolean      read_done_item_is_writable( const NAIFactoryProvider *provi
 static void          read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectAction 
*action, ReaderData *data, GSList **messages );
 static void          read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *data, 
const gchar *path, GSList **messages );
 
-static NADataBoxed  *get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, ReaderData 
*reader_data, const NADataDef *def );
+static FMADataBoxed  *get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, ReaderData 
*reader_data, const NADataDef *def );
 static gboolean      is_key_writable( NagpGConfProvider *gconf, const gchar *key );
 
 /*
@@ -195,11 +195,11 @@ read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectP
        na_object_attach_profile( data->parent, profile );
 }
 
-NADataBoxed *
+FMADataBoxed *
 nagp_reader_read_data( const NAIFactoryProvider *provider, void *reader_data, const NAIFactoryObject 
*object, const NADataDef *def, GSList **messages )
 {
        static const gchar *thisfn = "nagp_reader_read_data";
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( provider ), NULL );
        g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NULL );
@@ -355,11 +355,11 @@ read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *d
        g_free( profile_data );
 }
 
-static NADataBoxed *
+static FMADataBoxed *
 get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, ReaderData *reader_data, const 
NADataDef *def )
 {
        static const gchar *thisfn = "nagp_reader_get_boxed_from_path";
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
        gboolean have_entry;
        gchar *str_value;
        gboolean bool_value;
@@ -372,7 +372,7 @@ get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, Reade
 
        if( have_entry ){
                gchar *entry_path = gconf_concat_dir_and_key( path, def->gconf_entry );
-               boxed = na_data_boxed_new( def );
+               boxed = fma_data_boxed_new( def );
 
                switch( def->type ){
 
diff --git a/src/io-gconf/nagp-reader.h b/src/io-gconf/nagp-reader.h
index ecb0e29..6db0597 100644
--- a/src/io-gconf/nagp-reader.h
+++ b/src/io-gconf/nagp-reader.h
@@ -38,7 +38,7 @@ G_BEGIN_DECLS
 GList       *nagp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages );
 
 void         nagp_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, GSList **messages  );
-NADataBoxed *nagp_reader_read_data ( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages );
+FMADataBoxed *nagp_reader_read_data ( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages );
 void         nagp_reader_read_done ( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, GSList **messages  );
 
 G_END_DECLS
diff --git a/src/io-gconf/nagp-writer.c b/src/io-gconf/nagp-writer.c
index dc4289a..9f58133 100644
--- a/src/io-gconf/nagp-writer.c
+++ b/src/io-gconf/nagp-writer.c
@@ -280,7 +280,7 @@ write_start_write_version( NagpGConfProvider *provider, NAObjectItem *item )
 
 guint
 nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
-                                                                       const NAIFactoryObject *object, const 
NADataBoxed *boxed,
+                                                                       const NAIFactoryObject *object, const 
FMADataBoxed *boxed,
                                                                        GSList **messages )
 {
        static const gchar *thisfn = "nagp_writer_write_data";
@@ -299,9 +299,9 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
        msg = NULL;
        code = NA_IIO_PROVIDER_CODE_OK;
-       def = na_data_boxed_get_data_def( boxed );
+       def = fma_data_boxed_get_data_def( boxed );
 
-       if( !na_data_boxed_is_default( boxed ) || def->write_if_default ){
+       if( !fma_data_boxed_is_default( boxed ) || def->write_if_default ){
 
                if( NA_IS_OBJECT_PROFILE( object )){
                        NAObjectItem *parent = NA_OBJECT_ITEM( na_object_get_parent( object ));
diff --git a/src/io-gconf/nagp-writer.h b/src/io-gconf/nagp-writer.h
index ad363fe..5e93909 100644
--- a/src/io-gconf/nagp-writer.h
+++ b/src/io-gconf/nagp-writer.h
@@ -30,7 +30,7 @@
 #ifndef __NAGP_WRITE_H__
 #define __NAGP_WRITE_H__
 
-#include <api/na-data-boxed.h>
+#include <api/fma-data-boxed.h>
 #include <api/na-iio-provider.h>
 #include <api/na-ifactory-provider.h>
 
@@ -58,7 +58,7 @@ guint    nagp_writer_write_start( const NAIFactoryProvider *writer, void *writer
                                                                        GSList **messages  );
 
 guint    nagp_writer_write_data ( const NAIFactoryProvider *provider, void *writer_data,
-                                                                       const NAIFactoryObject *object, const 
NADataBoxed *boxed,
+                                                                       const NAIFactoryObject *object, const 
FMADataBoxed *boxed,
                                                                        GSList **messages );
 
 guint    nagp_writer_write_done ( const NAIFactoryProvider *writer, void *writer_data,
diff --git a/src/io-xml/naxml-reader.c b/src/io-xml/naxml-reader.c
index d573592..f92efc3 100644
--- a/src/io-xml/naxml-reader.c
+++ b/src/io-xml/naxml-reader.c
@@ -155,7 +155,7 @@ static RootNodeStr st_root_node_str[] = {
 
 static void          read_start_profile_attach_profile( NAXMLReader *reader, NAObjectProfile *profile );
 static gboolean      read_data_is_path_adhoc_for_object( NAXMLReader *reader, const NAIFactoryObject 
*object, xmlChar *text );
-static NADataBoxed  *read_data_boxed_from_node( NAXMLReader *reader, xmlChar *text, xmlNode *parent, const 
NADataDef *def );
+static FMADataBoxed  *read_data_boxed_from_node( NAXMLReader *reader, xmlChar *text, xmlNode *parent, const 
NADataDef *def );
 static void          read_done_item_set_localized_icon( NAXMLReader *reader, NAObjectItem *item );
 static void          read_done_action_read_profiles( NAXMLReader *reader, NAObjectAction *action );
 static gchar        *read_done_action_get_next_profile_id( NAXMLReader *reader );
@@ -629,7 +629,7 @@ read_start_profile_attach_profile( NAXMLReader *reader, NAObjectProfile *profile
  * of the same data (e.g. icon which exists in localized and unlocalized
  * versions). So do not remove dealt-with nodes here
  */
-NADataBoxed *
+FMADataBoxed *
 naxml_reader_read_data( const NAIFactoryProvider *provider, void *reader_data, const NAIFactoryObject 
*object, const NADataDef *def, GSList **messages )
 {
        static const gchar *thisfn = "naxml_reader_read_data";
@@ -647,7 +647,7 @@ naxml_reader_read_data( const NAIFactoryProvider *provider, void *reader_data, c
                return( NULL );
        }
 
-       NADataBoxed *boxed = NULL;
+       FMADataBoxed *boxed = NULL;
        NAXMLReader *reader = NAXML_READER( reader_data );
 
        /*g_debug( "naxml_reader_read_data: nodes=%p (count=%d)",
@@ -723,10 +723,10 @@ read_data_is_path_adhoc_for_object( NAXMLReader *reader, const NAIFactoryObject
        return( adhoc );
 }
 
-static NADataBoxed *
+static FMADataBoxed *
 read_data_boxed_from_node( NAXMLReader *reader, xmlChar *path, xmlNode *parent, const NADataDef *def )
 {
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
        gchar *entry;
        gchar *value;
 
@@ -742,7 +742,7 @@ read_data_boxed_from_node( NAXMLReader *reader, xmlChar *path, xmlNode *parent,
 
                if( reader->private->root_node_str->fn_get_value ){
                        value = ( *reader->private->root_node_str->fn_get_value )( reader, parent, def );
-                       boxed = na_data_boxed_new( def );
+                       boxed = fma_data_boxed_new( def );
                        fma_boxed_set_from_string( FMA_BOXED( boxed ), value );
                        g_free( value );
                }
diff --git a/src/io-xml/naxml-reader.h b/src/io-xml/naxml-reader.h
index 326f4d9..6f68737 100644
--- a/src/io-xml/naxml-reader.h
+++ b/src/io-xml/naxml-reader.h
@@ -44,7 +44,7 @@
  * #NAObjectItem-derived object.
  */
 
-#include <api/na-data-boxed.h>
+#include <api/fma-data-boxed.h>
 #include <api/na-iimporter.h>
 #include <api/na-ifactory-provider.h>
 
@@ -80,7 +80,7 @@ GType        naxml_reader_get_type( void );
 guint        naxml_reader_import_from_uri( const NAIImporter *instance, void *parms_ptr );
 
 void         naxml_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, GSList **messages  );
-NADataBoxed *naxml_reader_read_data ( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages );
+FMADataBoxed *naxml_reader_read_data ( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages );
 void         naxml_reader_read_done ( const NAIFactoryProvider *provider, void *reader_data, const 
NAIFactoryObject *object, GSList **messages  );
 
 G_END_DECLS
diff --git a/src/io-xml/naxml-writer.c b/src/io-xml/naxml-writer.c
index e46b3ed..3b74357 100644
--- a/src/io-xml/naxml-writer.c
+++ b/src/io-xml/naxml-writer.c
@@ -87,7 +87,7 @@ struct ExportFormatFn {
        gchar  *list_node;
        void ( *write_list_attribs_fn )( NAXMLWriter *, const NAObjectItem * );
        gchar  *element_node;
-       void ( *write_data_fn )( NAXMLWriter *, const NAObjectId *, const NADataBoxed *, const NADataDef * );
+       void ( *write_data_fn )( NAXMLWriter *, const NAObjectId *, const FMADataBoxed *, const NADataDef * );
        void ( *write_type_fn )( NAXMLWriter *, const NAObjectItem *, const NADataDef *, const gchar * );
 };
 
@@ -102,15 +102,15 @@ static void            instance_finalize( GObject *object );
 static void            write_start_write_type( NAXMLWriter *writer, NAObjectItem *object, const NADataGroup 
*groups );
 static void            write_start_write_version( NAXMLWriter *writer, NAObjectItem *object, const 
NADataGroup *groups );
 
-static void            write_data_schema_v1( NAXMLWriter *writer, const NAObjectId *object, const 
NADataBoxed *boxed, const NADataDef *def );
+static void            write_data_schema_v1( NAXMLWriter *writer, const NAObjectId *object, const 
FMADataBoxed *boxed, const NADataDef *def );
 static void            write_data_schema_v1_element( NAXMLWriter *writer, const NADataDef *def );
 static void            write_type_schema_v1( NAXMLWriter *writer, const NAObjectItem *object, const 
NADataDef *def, const gchar *value );
-static void            write_data_schema_v2( NAXMLWriter *writer, const NAObjectId *object, const 
NADataBoxed *boxed, const NADataDef *def );
+static void            write_data_schema_v2( NAXMLWriter *writer, const NAObjectId *object, const 
FMADataBoxed *boxed, const NADataDef *def );
 static void            write_data_schema_v2_element( NAXMLWriter *writer, const NADataDef *def, const gchar 
*object_id, const gchar *value_str );
 static void            write_type_schema_v2( NAXMLWriter *writer, const NAObjectItem *object, const 
NADataDef *def, const gchar *value );
 static void            write_list_attribs_dump( NAXMLWriter *writer, const NAObjectItem *object );
-static void            write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxed 
*boxed, const NADataDef *def );
-static void            write_data_dump_element( NAXMLWriter *writer, const NADataDef *def, const NADataBoxed 
*boxed, const gchar *entry, const gchar *value_str );
+static void            write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const FMADataBoxed 
*boxed, const NADataDef *def );
+static void            write_data_dump_element( NAXMLWriter *writer, const NADataDef *def, const 
FMADataBoxed *boxed, const gchar *entry, const gchar *value_str );
 static void            write_type_dump( NAXMLWriter *writer, const NAObjectItem *object, const NADataDef 
*def, const gchar *value );
 
 static xmlDocPtr       build_xml_doc( NAXMLWriter *writer );
@@ -471,19 +471,19 @@ write_start_write_version( NAXMLWriter *writer, NAObjectItem *object, const NADa
 }
 
 guint
-naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject 
*object, const NADataBoxed *boxed, GSList **messages )
+naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject 
*object, const FMADataBoxed *boxed, GSList **messages )
 {
        NAXMLWriter *writer;
        const NADataDef *def;
 
-       /*NADataDef *def = na_data_boxed_get_data_def( boxed );
+       /*NADataDef *def = fma_data_boxed_get_data_def( boxed );
        g_debug( "naxml_writer_write_data: def=%s", def->name );*/
 
-       def = na_data_boxed_get_data_def( boxed );
+       def = fma_data_boxed_get_data_def( boxed );
 
        /* do no export empty values
         */
-       if( !na_data_boxed_is_default( boxed ) || def->write_if_default ){
+       if( !fma_data_boxed_is_default( boxed ) || def->write_if_default ){
 
                writer = NAXML_WRITER( writer_data );
 
@@ -503,7 +503,7 @@ naxml_writer_write_done( const NAIFactoryProvider *provider, void *writer_data,
 }
 
 static void
-write_data_schema_v1( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxed *boxed, const 
NADataDef *def )
+write_data_schema_v1( NAXMLWriter *writer, const NAObjectId *object, const FMADataBoxed *boxed, const 
NADataDef *def )
 {
        write_data_schema_v2( writer, object, boxed, def );
 
@@ -541,7 +541,7 @@ write_type_schema_v1( NAXMLWriter *writer, const NAObjectItem *object, const NAD
  *  <applyto>/apps/file-manager-actions/configurations/item_id/profile_id/entry</applyto>
  */
 static void
-write_data_schema_v2( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxed *boxed, const 
NADataDef *def )
+write_data_schema_v2( NAXMLWriter *writer, const NAObjectId *object, const FMADataBoxed *boxed, const 
NADataDef *def )
 {
        gchar *object_id;
        gchar *value_str;
@@ -653,7 +653,7 @@ write_list_attribs_dump( NAXMLWriter *writer, const NAObjectItem *object )
 }
 
 static void
-write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxed *boxed, const NADataDef 
*def )
+write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const FMADataBoxed *boxed, const NADataDef 
*def )
 {
        gchar *entry;
        gchar *value_str;
@@ -693,7 +693,7 @@ write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxe
 }
 
 static void
-write_data_dump_element( NAXMLWriter *writer, const NADataDef *def, const NADataBoxed *boxed, const gchar 
*entry, const gchar *value_str )
+write_data_dump_element( NAXMLWriter *writer, const NADataDef *def, const FMADataBoxed *boxed, const gchar 
*entry, const gchar *value_str )
 {
        xmlNodePtr entry_node;
        xmlNodePtr value_node;
diff --git a/src/io-xml/naxml-writer.h b/src/io-xml/naxml-writer.h
index 4619b7e..b50a9bd 100644
--- a/src/io-xml/naxml-writer.h
+++ b/src/io-xml/naxml-writer.h
@@ -38,7 +38,7 @@
  * This class exports FileManager-Actions actions and menus as XML files.
  */
 
-#include <api/na-data-boxed.h>
+#include <api/fma-data-boxed.h>
 #include <api/na-iexporter.h>
 #include <api/na-ifactory-provider.h>
 
@@ -75,7 +75,7 @@ guint  naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBu
 guint  naxml_writer_export_to_file  ( const NAIExporter *instance, NAIExporterFileParmsv2 *parms );
 
 guint  naxml_writer_write_start( const NAIFactoryProvider *writer, void *writer_data, const NAIFactoryObject 
*object, GSList **messages  );
-guint  naxml_writer_write_data ( const NAIFactoryProvider *writer, void *writer_data, const NAIFactoryObject 
*object, const NADataBoxed *boxed, GSList **messages );
+guint  naxml_writer_write_data ( const NAIFactoryProvider *writer, void *writer_data, const NAIFactoryObject 
*object, const FMADataBoxed *boxed, GSList **messages );
 guint  naxml_writer_write_done ( const NAIFactoryProvider *writer, void *writer_data, const NAIFactoryObject 
*object, GSList **messages  );
 
 G_END_DECLS


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/api/na-ifactory-provider.h b/src/api/na-ifactory-provider.h
index 84234fb..b314f4d 100644
--- a/src/api/na-ifactory-provider.h
+++ b/src/api/na-ifactory-provider.h
@@ -56,7 +56,7 @@
  *       <para>
  *         whether they are a string, an integer, a boolean, a simple
  *         or double-linked list, each elementary data is encapsuled
  *         into a #NADataBoxed, small sort of structure (incidentally,
  *         which acts almost as the new GLib #GVariant, but too late,
  *         guys :)).
  *       </para>
@@ -67,7 +67,7 @@
  *       <title>Our objects are de-structured.</title>
  *       <para>
  *         Instead of organizing our elementary datas into structures,
  *         our objects are just flat lists of #NADataBoxed.
  *       </para>
  *     </formalpara>
  *   </listitem>
@@ -134,7 +134,7 @@
  * </refsect2>
  */
 
-#include "na-data-boxed.h"
+#include "fma-data-boxed.h"
 #include "na-ifactory-object.h"
 #include "na-ifactory-provider-provider.h"
 
@@ -204,12 +204,12 @@ typedef struct {
         *
         * This method must be implemented in order any data be read.
         *
         * Returns: a newly allocated NADataBoxed which contains the read value.
         * Should return %NULL if data is not found.
         *
         * Since: 2.30
         */
-       NADataBoxed * ( *read_data )  ( const NAIFactoryProvider *reader, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages );
+       FMADataBoxed * ( *read_data )  ( const NAIFactoryProvider *reader, void *reader_data, const 
NAIFactoryObject *object, const NADataDef *def, GSList **messages );
 
        /**
         * read_done:
@@ -249,7 +249,7 @@ typedef struct {
         * @writer_data: the data associated to this instance.
         * @object: the #NAIFactoryObject object being written.
         * @def: the description of the data to be written.
         * @value: the #NADataBoxed to be written down.
         * @messages: a pointer to a #GSList list of strings; the provider
         *  may append messages to this list, but shouldn't reinitialize it.
         *
@@ -261,7 +261,7 @@ typedef struct {
         *
         * Since: 2.30
         */
-       guint         ( *write_data ) ( const NAIFactoryProvider *writer, void *writer_data, const 
NAIFactoryObject *object, const NADataBoxed *boxed, GSList **messages );
+       guint         ( *write_data ) ( const NAIFactoryProvider *writer, void *writer_data, const 
NAIFactoryObject *object, const FMADataBoxed *boxed, GSList **messages );
 
        /**
@@ -56,7 +56,7 @@
  *         whether they are a string, an integer, a boolean, a simple
  *         or double-linked list, each elementary data is encapsuled
- *         into a #NADataBoxed, small sort of structure (incidentally,
+ *         into a #FMADataBoxed, small sort of structure (incidentally,
  *         which acts almost as the new GLib #GVariant, but too late,
  *         guys :)).
@@ -67,7 +67,7 @@
  *       <para>
  *         Instead of organizing our elementary datas into structures,
- *         our objects are just flat lists of #NADataBoxed.
+ *         our objects are just flat lists of #FMADataBoxed.
  *       </para>
  *     </formalpara>
@@ -204,12 +204,12 @@ typedef struct {
         * This method must be implemented in order any data be read.
         *
-        * Returns: a newly allocated NADataBoxed which contains the read value.
+        * Returns: a newly allocated FMADataBoxed which contains the read value.
         * Should return %NULL if data is not found.
         *
@@ -249,7 +249,7 @@ typedef struct {
         * @object: the #NAIFactoryObject object being written.
         * @def: the description of the data to be written.
-        * @value: the #NADataBoxed to be written down.
+        * @value: the #FMADataBoxed to be written down.
         * @messages: a pointer to a #GSList list of strings; the provider
         *  may append messages to this list, but shouldn't reinitialize it.
         * write_done:
diff --git a/src/core/na-factory-object.c b/src/core/na-factory-object.c
index 2f9a203..58984cf 100644
--- a/src/core/na-factory-object.c
+++ b/src/core/na-factory-object.c
@@ -36,7 +36,7 @@
 #include <string.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-data-boxed.h>
+#include <api/fma-data-boxed.h>
 #include <api/na-data-types.h>
 #include <api/na-iio-provider.h>
 #include <api/na-ifactory-provider.h>
@@ -96,7 +96,7 @@ static gboolean     define_class_properties_iter( const NADataDef *def, GObjectC
 static gboolean     set_defaults_iter( NADataDef *def, NafoDefaultIter *data );
 static gboolean     is_valid_mandatory_iter( const NADataDef *def, NafoValidIter *data );
 static gboolean     read_data_iter( NADataDef *def, NafoReadIter *iter );
-static gboolean     write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIter *iter 
);
+static gboolean     write_data_iter( const NAIFactoryObject *object, FMADataBoxed *boxed, NafoWriteIter 
*iter );
 
 static NADataGroup *v_get_groups( const NAIFactoryObject *object );
 static void         v_copy( NAIFactoryObject *target, const NAIFactoryObject *source );
@@ -107,7 +107,7 @@ static void         v_read_done( NAIFactoryObject *serializable, const NAIFactor
 static guint        v_write_start( NAIFactoryObject *serializable, const NAIFactoryProvider *reader, void 
*reader_data, GSList **messages );
 static guint        v_write_done( NAIFactoryObject *serializable, const NAIFactoryProvider *reader, void 
*reader_data, GSList **messages );
 
-static void         attach_boxed_to_object( NAIFactoryObject *object, NADataBoxed *boxed );
+static void         attach_boxed_to_object( NAIFactoryObject *object, FMADataBoxed *boxed );
 static void         free_data_boxed_list( NAIFactoryObject *object );
 static void         iter_on_data_defs( const NADataGroup *idgroups, guint mode, NADataDefIterFunc pfn, void 
*user_data );
 
@@ -144,7 +144,7 @@ define_class_properties_iter( const NADataDef *def, GObjectClass *class )
 
        stop = FALSE;
 
-       spec = na_data_boxed_get_param_spec( def );
+       spec = fma_data_boxed_get_param_spec( def );
 
        if( spec ){
                g_object_class_install_property( class, g_quark_from_string( def->name ), spec );
@@ -215,7 +215,7 @@ na_factory_object_get_data_groups( const NAIFactoryObject *object )
  * @pfn: the function to be called.
  * @user_data: data to be provided to the user function.
  *
  * Iterate on each #NADataBoxed attached to the @object.
  *
  * The @fn called function may return %TRUE to stop the iteration.
  */
@@ -232,7 +232,7 @@ na_factory_object_iter_on_boxed( const NAIFactoryObject *object, NAFactoryObject
        stop = FALSE;
 
        for( ibox = list ; ibox && !stop ; ibox = ibox->next ){
-               stop = ( *pfn )( object, NA_DATA_BOXED( ibox->data ), user_data );
+               stop = ( *pfn )( object, FMA_DATA_BOXED( ibox->data ), user_data );
        }
 }
 
@@ -298,17 +298,17 @@ na_factory_object_set_defaults( NAIFactoryObject *object )
 
 /*
  * because this function is called very early in the NAIFactoryObject life,
  * we assume here that if a NADataBoxed has been allocated, then this is
  * most probably because it is set. Thus a 'null' value is not considered
  * as an 'unset' value.
  */
 static gboolean
 set_defaults_iter( NADataDef *def, NafoDefaultIter *data )
 {
-       NADataBoxed *boxed = na_ifactory_object_get_data_boxed( data->object, def->name );
+       FMADataBoxed *boxed = na_ifactory_object_get_data_boxed( data->object, def->name );
 
        if( !boxed ){
-               boxed = na_data_boxed_new( def );
+               boxed = fma_data_boxed_new( def );
                attach_boxed_to_object( data->object, boxed );
                fma_boxed_set_from_string( FMA_BOXED( boxed ), def->default_value );
        }
@@ -321,13 +321,13 @@ set_defaults_iter( NADataDef *def, NafoDefaultIter *data )
  * na_factory_object_move_boxed:
  * @target: the target #NAIFactoryObject instance.
  * @source: the source #NAIFactoryObject instance.
- * @boxed: a #NADataBoxed.
+ * @boxed: a #FMADataBoxed.
  *
  * Move the @boxed from @source to @target, detaching from @source list
  * to be attached to @target one.
  */
 void
-na_factory_object_move_boxed( NAIFactoryObject *target, const NAIFactoryObject *source, NADataBoxed *boxed )
+na_factory_object_move_boxed( NAIFactoryObject *target, const NAIFactoryObject *source, FMADataBoxed *boxed )
 {
        g_return_if_fail( NA_IS_IFACTORY_OBJECT( target ));
        g_return_if_fail( NA_IS_IFACTORY_OBJECT( source ));
@@ -340,9 +340,9 @@ na_factory_object_move_boxed( NAIFactoryObject *target, const NAIFactoryObject *
 
                attach_boxed_to_object( target, boxed );
 
-               const NADataDef *src_def = na_data_boxed_get_data_def( boxed );
+               const NADataDef *src_def = fma_data_boxed_get_data_def( boxed );
                NADataDef *tgt_def = na_factory_object_get_data_def( target, src_def->name );
-               na_data_boxed_set_data_def( boxed, tgt_def );
+               fma_data_boxed_set_data_def( boxed, tgt_def );
        }
 }
 
@@ -360,7 +360,7 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
        static const gchar *thisfn = "na_factory_object_copy";
        GList *dest_list, *idest, *inext;
        GList *src_list, *isrc;
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
        const NADataDef *def;
        void *provider, *provider_data;
 
@@ -379,9 +379,9 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
 
        idest = dest_list = g_object_get_data( G_OBJECT( target ), NA_IFACTORY_OBJECT_PROP_DATA );
        while( idest ){
-               boxed = NA_DATA_BOXED( idest->data );
+               boxed = FMA_DATA_BOXED( idest->data );
                inext = idest->next;
-               def = na_data_boxed_get_data_def( boxed );
+               def = fma_data_boxed_get_data_def( boxed );
                if( def->copyable ){
                        dest_list = g_list_remove_link( dest_list, idest );
                        g_object_unref( idest->data );
@@ -394,12 +394,12 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
         */
        src_list = g_object_get_data( G_OBJECT( source ), NA_IFACTORY_OBJECT_PROP_DATA );
        for( isrc = src_list ; isrc ; isrc = isrc->next ){
-               boxed = NA_DATA_BOXED( isrc->data );
-               def = na_data_boxed_get_data_def( boxed );
+               boxed = FMA_DATA_BOXED( isrc->data );
+               def = fma_data_boxed_get_data_def( boxed );
                if( def->copyable ){
-                       NADataBoxed *tgt_boxed = na_ifactory_object_get_data_boxed( target, def->name );
+                       FMADataBoxed *tgt_boxed = na_ifactory_object_get_data_boxed( target, def->name );
                        if( !tgt_boxed ){
-                               tgt_boxed = na_data_boxed_new( def );
+                               tgt_boxed = fma_data_boxed_new( def );
                                attach_boxed_to_object( target, tgt_boxed );
                        }
                        fma_boxed_set_from_boxed( FMA_BOXED( tgt_boxed ), FMA_BOXED( boxed ));
@@ -440,11 +440,11 @@ na_factory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *
        are_equal = TRUE;
        for( ia = a_list ; ia && are_equal ; ia = ia->next ){
 
-               NADataBoxed *a_boxed = NA_DATA_BOXED( ia->data );
-               const NADataDef *a_def = na_data_boxed_get_data_def( a_boxed );
+               FMADataBoxed *a_boxed = FMA_DATA_BOXED( ia->data );
+               const NADataDef *a_def = fma_data_boxed_get_data_def( a_boxed );
                if( a_def->comparable ){
 
-                       NADataBoxed *b_boxed = na_ifactory_object_get_data_boxed( b, a_def->name );
+                       FMADataBoxed *b_boxed = na_ifactory_object_get_data_boxed( b, a_def->name );
                        if( b_boxed ){
                                are_equal = fma_boxed_are_equal( FMA_BOXED( a_boxed ), FMA_BOXED( b_boxed ));
                                if( !are_equal ){
@@ -460,11 +460,11 @@ na_factory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *
 
        for( ib = b_list ; ib && are_equal ; ib = ib->next ){
 
-               NADataBoxed *b_boxed = NA_DATA_BOXED( ib->data );
-               const NADataDef *b_def = na_data_boxed_get_data_def( b_boxed );
+               FMADataBoxed *b_boxed = FMA_DATA_BOXED( ib->data );
+               const NADataDef *b_def = fma_data_boxed_get_data_def( b_boxed );
                if( b_def->comparable ){
 
-                       NADataBoxed *a_boxed = na_ifactory_object_get_data_boxed( a, b_def->name );
+                       FMADataBoxed *a_boxed = na_ifactory_object_get_data_boxed( a, b_def->name );
                        if( !a_boxed ){
                                are_equal = FALSE;
                                g_debug( "%s: %s not equal as %s was not set", thisfn, G_OBJECT_TYPE_NAME( a 
), b_def->name );
@@ -511,7 +511,7 @@ na_factory_object_is_valid( const NAIFactoryObject *object )
        is_valid = iter_data.is_valid;
 
        for( iv = list ; iv && is_valid ; iv = iv->next ){
-               is_valid = na_data_boxed_is_valid( NA_DATA_BOXED( iv->data ));
+               is_valid = fma_data_boxed_is_valid( FMA_DATA_BOXED( iv->data ));
        }
 
        is_valid &= v_is_valid( object );
@@ -522,7 +522,7 @@ na_factory_object_is_valid( const NAIFactoryObject *object )
 static gboolean
 is_valid_mandatory_iter( const NADataDef *def, NafoValidIter *data )
 {
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        if( def->mandatory ){
                boxed = na_ifactory_object_get_data_boxed( data->object, def->name );
@@ -556,8 +556,8 @@ na_factory_object_dump( const NAIFactoryObject *object )
        list = g_object_get_data( G_OBJECT( object ), NA_IFACTORY_OBJECT_PROP_DATA );
 
        for( it = list ; it ; it = it->next ){
-               NADataBoxed *boxed = NA_DATA_BOXED( it->data );
-               const NADataDef *def = na_data_boxed_get_data_def( boxed );
+               FMADataBoxed *boxed = FMA_DATA_BOXED( it->data );
+               const NADataDef *def = fma_data_boxed_get_data_def( boxed );
                length = MAX( length, strlen( def->name ));
        }
 
@@ -565,8 +565,8 @@ na_factory_object_dump( const NAIFactoryObject *object )
        length += 1;
 
        for( it = list ; it ; it = it->next ){
-               NADataBoxed *boxed = NA_DATA_BOXED( it->data );
-               const NADataDef *def = na_data_boxed_get_data_def( boxed );
+               FMADataBoxed *boxed = FMA_DATA_BOXED( it->data );
+               const NADataDef *def = fma_data_boxed_get_data_def( boxed );
                gchar *value = fma_boxed_get_string( FMA_BOXED( boxed ));
                g_debug( "| %s: %*s=%s", thisfn, length, def->name+l_prefix, value );
                g_free( value );
@@ -633,10 +633,10 @@ read_data_iter( NADataDef *def, NafoReadIter *iter )
 
        stop = FALSE;
 
-       NADataBoxed *boxed = na_factory_provider_read_data( iter->reader, iter->reader_data, iter->object, 
def, iter->messages );
+       FMADataBoxed *boxed = na_factory_provider_read_data( iter->reader, iter->reader_data, iter->object, 
def, iter->messages );
 
        if( boxed ){
-               NADataBoxed *exist = na_ifactory_object_get_data_boxed( iter->object, def->name );
+               FMADataBoxed *exist = na_ifactory_object_get_data_boxed( iter->object, def->name );
 
                if( exist ){
                        fma_boxed_set_from_boxed( FMA_BOXED( exist ), FMA_BOXED( boxed ));
@@ -709,9 +709,9 @@ na_factory_object_write_item( NAIFactoryObject *object, const NAIFactoryProvider
 }
 
 static gboolean
-write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIter *iter )
+write_data_iter( const NAIFactoryObject *object, FMADataBoxed *boxed, NafoWriteIter *iter )
 {
-       const NADataDef *def = na_data_boxed_get_data_def( boxed );
+       const NADataDef *def = fma_data_boxed_get_data_def( boxed );
 
        if( def->writable ){
                iter->code = na_factory_provider_write_data( iter->writer, iter->writer_data, object, boxed, 
iter->messages );
@@ -727,7 +727,7 @@ write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIt
  * @name: the elementary data id.
  * @value: the #GValue to be set.
  *
  * Set the @value with the current content of the #NADataBoxed attached
  * to @name.
  *
  * This is to be read as "set value from data element".
@@ -735,7 +735,7 @@ write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIt
 void
 na_factory_object_get_as_value( const NAIFactoryObject *object, const gchar *name, GValue *value )
 {
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 
@@ -763,7 +763,7 @@ void *
 na_factory_object_get_as_void( const NAIFactoryObject *object, const gchar *name )
 {
        void *value;
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NULL );
 
@@ -787,7 +787,7 @@ na_factory_object_get_as_void( const NAIFactoryObject *object, const gchar *name
 gboolean
 na_factory_object_is_set( const NAIFactoryObject *object, const gchar *name )
 {
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), FALSE );
 
@@ -802,7 +802,7 @@ na_factory_object_is_set( const NAIFactoryObject *object, const gchar *name )
  * @name: the elementary data id.
  * @value: the #GValue whose content is to be got.
  *
  * Get from the @value the content to be set in the #NADataBoxed
  * attached to @property_id.
  */
 void
@@ -812,7 +812,7 @@ na_factory_object_set_from_value( NAIFactoryObject *object, const gchar *name, c
 
        g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 
-       NADataBoxed *boxed = na_ifactory_object_get_data_boxed( object, name );
+       FMADataBoxed *boxed = na_ifactory_object_get_data_boxed( object, name );
        if( boxed ){
                fma_boxed_set_from_value( FMA_BOXED( boxed ), value );
 
@@ -822,7 +822,7 @@ na_factory_object_set_from_value( NAIFactoryObject *object, const gchar *name, c
                        g_warning( "%s: unknown NADataDef %s", thisfn, name );
 
                } else {
-                       boxed = na_data_boxed_new( def );
+                       boxed = fma_data_boxed_new( def );
                        fma_boxed_set_from_value( FMA_BOXED( boxed ), value );
                        attach_boxed_to_object( object, boxed );
                }
@@ -844,7 +844,7 @@ na_factory_object_set_from_void( NAIFactoryObject *object, const gchar *name, co
 
        g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 
-       NADataBoxed *boxed = na_ifactory_object_get_data_boxed( object, name );
+       FMADataBoxed *boxed = na_ifactory_object_get_data_boxed( object, name );
        if( boxed ){
                fma_boxed_set_from_void( FMA_BOXED( boxed ), data );
 
@@ -854,7 +854,7 @@ na_factory_object_set_from_void( NAIFactoryObject *object, const gchar *name, co
                        g_warning( "%s: unknown NADataDef %s for %s", thisfn, name, G_OBJECT_TYPE_NAME( 
object ));
 
                } else {
-                       boxed = na_data_boxed_new( def );
+                       boxed = fma_data_boxed_new( def );
                        fma_boxed_set_from_void( FMA_BOXED( boxed ), data );
                        attach_boxed_to_object( object, boxed );
                }
@@ -940,7 +940,7 @@ v_write_done( NAIFactoryObject *serializable, const NAIFactoryProvider *writer,
 }
 
 static void
-attach_boxed_to_object( NAIFactoryObject *object, NADataBoxed *boxed )
+attach_boxed_to_object( NAIFactoryObject *object, FMADataBoxed *boxed )
 {
        GList *list = g_object_get_data( G_OBJECT( object ), NA_IFACTORY_OBJECT_PROP_DATA );
        list = g_list_prepend( list, boxed );
@@ -215,7 +215,7 @@ na_factory_object_get_data_groups( const NAIFactoryObject *object )
  * @user_data: data to be provided to the user function.
  *
- * Iterate on each #NADataBoxed attached to the @object.
+ * Iterate on each #FMADataBoxed attached to the @object.
  *
  * The @fn called function may return %TRUE to stop the iteration.
@@ -298,17 +298,17 @@ na_factory_object_set_defaults( NAIFactoryObject *object )
 /*
  * because this function is called very early in the NAIFactoryObject life,
- * we assume here that if a NADataBoxed has been allocated, then this is
+ * we assume here that if a FMADataBoxed has been allocated, then this is
  * most probably because it is set. Thus a 'null' value is not considered
  * as an 'unset' value.
@@ -727,7 +727,7 @@ write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIt
  * @value: the #GValue to be set.
  *
- * Set the @value with the current content of the #NADataBoxed attached
+ * Set the @value with the current content of the #FMADataBoxed attached
  * to @name.
  *
@@ -802,7 +802,7 @@ na_factory_object_is_set( const NAIFactoryObject *object, const gchar *name )
  * @value: the #GValue whose content is to be got.
  *
- * Get from the @value the content to be set in the #NADataBoxed
+ * Get from the @value the content to be set in the #FMADataBoxed
  * attached to @property_id.
  */
diff --git a/src/core/na-factory-provider.c b/src/core/na-factory-provider.c
index 9191cc6..2a56f1a 100644
--- a/src/core/na-factory-provider.c
+++ b/src/core/na-factory-provider.c
@@ -46,14 +46,14 @@
  *
  * Reads the specified data and set it up into the @boxed.
  *
  * Returns: a new #NADataBoxed object which contains the data.
  */
-NADataBoxed *
+FMADataBoxed *
 na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data,
                                                                const NAIFactoryObject *object, const 
NADataDef *def,
                                                                GSList **messages )
 {
-       NADataBoxed *boxed;
+       FMADataBoxed *boxed;
 
        g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( reader ), NULL );
        g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NULL );
@@ -72,7 +72,7 @@ na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_da
  * @writer: the instance which implements this #NAIFactoryProvider interface.
  * @writer_data: instance data.
  * @object: the #NAIFactoryobject being serialized.
  * @boxed: the #NADataBoxed object which is to be serialized.
  * @messages: a pointer to a #GSList list of strings; the implementation
  *  may append messages to this list, but shouldn't reinitialize it.
  *
@@ -80,7 +80,7 @@ na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_da
  */
 guint
 na_factory_provider_write_data( const NAIFactoryProvider *writer, void *writer_data,
-                                                               const NAIFactoryObject *object, const 
NADataBoxed *boxed,
+                                                               const NAIFactoryObject *object, const 
FMADataBoxed *boxed,
                                                                GSList **messages )
 {
@@ -46,14 +46,14 @@
  * Reads the specified data and set it up into the @boxed.
  *
- * Returns: a new #NADataBoxed object which contains the data.
+ * Returns: a new #FMADataBoxed object which contains the data.
  */
@@ -72,7 +72,7 @@ na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_da
  * @writer_data: instance data.
  * @object: the #NAIFactoryobject being serialized.
- * @boxed: the #NADataBoxed object which is to be serialized.
+ * @boxed: the #FMADataBoxed object which is to be serialized.
  * @messages: a pointer to a #GSList list of strings; the implementation
  *  may append messages to this list, but shouldn't reinitialize it.
        guint code;
diff --git a/src/core/na-ifactory-object.c b/src/core/na-ifactory-object.c
index e2cb8a5..b0780c5 100644
--- a/src/core/na-ifactory-object.c
+++ b/src/core/na-ifactory-object.c
@@ -144,15 +144,15 @@ ifactory_object_get_version( const NAIFactoryObject *instance )
  * @object: a #NAIFactoryObject object.
  * @name: the name of the elementary data we are searching for.
  *
  * The returned #NADataBoxed is owned by #NAIFactoryObject @object, and
  * should not be released by the caller.
  *
  * Returns: The #NADataBoxed object which contains the specified data,
  * or %NULL.
  *
  * Since: 2.30
  */
-NADataBoxed *
+FMADataBoxed *
 na_ifactory_object_get_data_boxed( const NAIFactoryObject *object, const gchar *name )
 {
        GList *list, *ip;
@@ -163,8 +163,8 @@ na_ifactory_object_get_data_boxed( const NAIFactoryObject *object, const gchar *
        /*g_debug( "list=%p (count=%u)", ( void * ) list, g_list_length( list ));*/
 
        for( ip = list ; ip ; ip = ip->next ){
-               NADataBoxed *boxed = NA_DATA_BOXED( ip->data );
-               const NADataDef *def = na_data_boxed_get_data_def( boxed );
+               FMADataBoxed *boxed = FMA_DATA_BOXED( ip->data );
+               const NADataDef *def = fma_data_boxed_get_data_def( boxed );
 
                if( !strcmp( def->name, name )){
                        return( boxed );
@@ -144,15 +144,15 @@ ifactory_object_get_version( const NAIFactoryObject *instance )
  * @name: the name of the elementary data we are searching for.
  *
- * The returned #NADataBoxed is owned by #NAIFactoryObject @object, and
+ * The returned #FMADataBoxed is owned by #NAIFactoryObject @object, and
  * should not be released by the caller.
  *
@@ -144,15 +144,15 @@ ifactory_object_get_version( const NAIFactoryObject *instance )
  * should not be released by the caller.
  *
- * Returns: The #NADataBoxed object which contains the specified data,
+ * Returns: The #FMADataBoxed object which contains the specified data,
  * or %NULL.
  *